fars_map_state: Make chart with plots of accidents locations in some state...

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

If state number doesn't exist error will be thrown. If there's no accidents in state for year message will be returned Otherwise map of state will accident locations will be created. All locations has to be within boundaries.

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

integer

year

in four digits

Value

plot chart

Examples

1
2
3
4
## Not run: 
fars_map_state(1, 2013)

## End(Not run)

kopipejst/vyyI documentation built on May 6, 2019, 8:34 p.m.