fars_read: Reading and parsing csv

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

It will check if file exist, try to parse as csv, and it will return data as data.frame In case that file doesn't exist it will return error. If file can't be parsed as csv error will be thrown.

Usage

1
fars_read(filename)

Arguments

filename

path to a data file

Value

data.frame

Examples

1
2
3
4
## Not run: 
fars_read('data/accident_2013.csv.bz2')

## End(Not run)

kopipejst/vyyI documentation built on May 6, 2019, 8:34 p.m.