fars_read_years: Add year variable to data, and return month, year list

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

It will add year variable for all requested years data, and return a list. In case that there's no data file for a year, warrning will be returned. Data files has to be in the same directory as this script.

Usage

1

Arguments

years

a vector of years

Value

list

Examples

1
2
3
4
5
6
## Not run: 
fars_read_years(2013)
fars_read_years(c('2013', 2014))
fars_read_years(c('2013', 2018, 2019))

## End(Not run)

kopipejst/vyyI documentation built on May 6, 2019, 8:34 p.m.