fars_summarize_years: Get count of records for each year by month

Description Usage Arguments Value Examples

View source: R/fars_functions.R

Description

For each requested year it will calculate count of records. Results for all years and months will be returned as data.frame In case that data from one of years doesn't exist warning will be returned for that year only.

Usage

1

Arguments

years

a vector of years

Value

data.frame

Examples

1
2
3
4
## Not run: 
fars_summarize_years(c('2013', 2014, 2015, 2018))

## End(Not run)

kopipejst/vyyI documentation built on May 6, 2019, 8:34 p.m.