Description Usage Arguments Value Examples
View source: R/fars_functions.R
If state number doesn't exist error will be thrown. If there's no accidents in state for year message will be returned Otherwise map of state will accident locations will be created. All locations has to be within boundaries.
1 | fars_map_state(state.num, year)
|
state.num |
integer |
year |
in four digits |
plot chart
1 2 3 4 | ## Not run:
fars_map_state(1, 2013)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.