Description Usage Arguments Value Examples
View source: R/fars_functions.R
It will check if file exist, try to parse as csv, and it will return data as data.frame In case that file doesn't exist it will return error. If file can't be parsed as csv error will be thrown.
1 | fars_read(filename)
|
filename |
path to a data file |
data.frame
1 2 3 4 | ## Not run:
fars_read('data/accident_2013.csv.bz2')
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.