Description Usage Arguments Value Examples
View source: R/fars_functions.R
It will add year variable for all requested years data, and return a list. In case that there's no data file for a year, warrning will be returned. Data files has to be in the same directory as this script.
1 | fars_read_years(years)
|
years |
a vector of years |
list
1 2 3 4 5 6 | ## Not run:
fars_read_years(2013)
fars_read_years(c('2013', 2014))
fars_read_years(c('2013', 2018, 2019))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.