Description Usage Arguments Value Examples
View source: R/fars_functions.R
For each requested year it will calculate count of records. Results for all years and months will be returned as data.frame In case that data from one of years doesn't exist warning will be returned for that year only.
1 | fars_summarize_years(years)
|
years |
a vector of years |
data.frame
1 2 3 4 | ## Not run:
fars_summarize_years(c('2013', 2014, 2015, 2018))
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.